
--| Calling elements from other lua files |--

local TUNING = GLOBAL.TUNING
local ACTIONS = GLOBAL.ACTIONS
local require = GLOBAL.require
local Armor = require "components/armor"
local FiniteUses = require "components/finiteuses"
local ItemTile = require "widgets/itemtile"
local KnownModIndex = GLOBAL.KnownModIndex
local SpawnPrefab = GLOBAL.SpawnPrefab

--| Detecting dlcs |--
local ROG = false
local SW = false
local PK = false
if(GLOBAL.IsDLCEnabled(GLOBAL.REIGN_OF_GIANTS)) then
	ROG = true
end
if(GLOBAL.IsDLCEnabled(GLOBAL.CAPY_DLC)) then
	SW = true
end
if(GLOBAL.IsDLCEnabled(GLOBAL.PORKLAND_DLC)) then
	PK = true
end

--| Getting user selections into local variables |--

local BATS = GetModConfigData("BATS")
local SPEARS = GetModConfigData("SPEARS")
local SWORDS = GetModConfigData("SWORDS")
local BOOMERANG = GetModConfigData("BOOMERANG")
local BOOMERANG_SPEED = GetModConfigData("BOOMERANG_SPEED")
local ARMOR_BODY = GetModConfigData("ARMOR_BODY")
local ARMOR_HAT = GetModConfigData("ARMOR_HAT")
local CLOTHS = GetModConfigData("CLOTHS")
local HATS = GetModConfigData("HATS")
local PRIMARY_TOOLS = GetModConfigData("PRIMARY_TOOLS")
local SURVIVAL_TOOLS = GetModConfigData("SURVIVAL_TOOLS")
local UMBRELLAS = GetModConfigData("UMBRELLAS")
local STAFFS = GetModConfigData("STAFFS")
local AMULETS = GetModConfigData("AMULETS")
local BOOKS = GetModConfigData("BOOKS")
local SEWINGKIT = GetModConfigData("SEWINGKIT")
local COMPASS = GetModConfigData("COMPASS")
local TRAPS = GetModConfigData("TRAPS")
local HEATROCK = GetModConfigData("HEATROCK")
local PORTABLE_LIGHT = GetModConfigData("PORTABLE_LIGHT")
local FIREPITS = GetModConfigData("FIREPITS")
local TORCH = GetModConfigData("TORCH")
local TORCH_RADIUS = GetModConfigData("TORCH_RADIUS")
local BEDROLLS = GetModConfigData("BEDROLLS")
local SHELTERS = GetModConfigData("SHELTERS")
local ICEBOX = GetModConfigData("ICEBOX")
local BOOST_GOLD = GetModConfigData("BOOST_GOLD")
local GOLD_ITEM_BONUS = GetModConfigData("GOLD_ITEM_BONUS")
local BOOST_OBSIDIAN = GetModConfigData("BOOST_OBSIDIAN")
local OBSIDIAN_ITEM_BONUS = GetModConfigData("OBSIDIAN_ITEM_BONUS")
local BOATS = GetModConfigData("BOATS")
local SAILS = GetModConfigData("SAILS")
local BOAT_ITEMS = GetModConfigData("BOAT_ITEMS")
local BOAT_REPAIRKIT = GetModConfigData("BOAT_REPAIRKIT")
local BLOWDART_USE = GetModConfigData("BLOWDART_USE")
local WALLS = GetModConfigData("WALLS")

--| Mod recognition |--

if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Madman's Fighting Pack")) then MadMan = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Gold Survival Kit")) then	GoldKit = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Ethereal spear")) then EtherealSpear = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Gold Hammer")) then GoldHammer = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Scythe")) then Scythe = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Fish Armor DST")) then FishArmor = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Fishbrella DST")) then FishHat = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Swordfish DST")) then	FishSword = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Mining Machine [DST]")) then MineMachine = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Basic Wooden Club")) then	WoodClub = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Knife")) then	Knife = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Sword")) then	Sword = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Fight Stick")) then FightStick = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Spider Blade DST")) then SpiderBlade = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Claymore")) then Claymore = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Endothermic Torch")) then	EndoTorch = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("linksword")) then	LinkSword = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Adventure Time Items")) then AdventureItems = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("DST Survival Gear")) then	SurvivalGear = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("ZoRcE's Sword MOD")) then	Zorce = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Golden Spear")) then GoldSpear = true end
if KnownModIndex:IsModEnabled(KnownModIndex:GetModActualName("Twicane")) then Twicane = true end

-- Remove % on itemslot for infinite items
	
local ItemTile_SetPercent = ItemTile.SetPercent
function ItemTile:SetPercent(percent)		
	if self.item:HasTag("Infinite") then 
		-- Nothing
	else
		ItemTile_SetPercent(self, percent)
	end
end

local ItemTile_SetQuantity = ItemTile.SetQuantity
function ItemTile:SetQuantity(quantity)
	if self.item:HasTag("Infinite") then
		-- Nothing
	else
		ItemTile_SetQuantity(self, quantity)
	end    
end

	--| Boost gold tools efficiency by two |--
	
if BOOST_GOLD then		
	local function BoostGoldenAxe(inst)
		inst.components.weapon:SetDamage(TUNING.AXE_DAMAGE*2)
		inst.components.tool:SetAction(ACTIONS.CHOP, 2)
	end
	local function BoostGoldenPickaxe(inst)	
		inst.components.weapon:SetDamage(TUNING.PICK_DAMAGE*2)
		inst.components.tool:SetAction(ACTIONS.MINE, 2)
	end
	local function BoostGoldenMachete(inst)
		inst.components.weapon:SetDamage(TUNING.MACHETE_DAMAGE*2)
		inst.components.tool:SetAction(ACTIONS.HACK, 2)
	end
	local function BoostGoldenShovel(inst)
		inst.components.weapon:SetDamage(TUNING.SHOVEL_DAMAGE*2)
		inst.components.tool:SetAction(ACTIONS.DIG, 2)
	end
	AddPrefabPostInit("goldenaxe", BoostGoldenAxe)
	AddPrefabPostInit("goldenpickaxe", BoostGoldenPickaxe)
	AddPrefabPostInit("goldenmachete", BoostGoldenMachete)
	AddPrefabPostInit("goldenshovel", BoostGoldenShovel)
end
	
	--| Boost obsidian tools efficiency by three |--
	
if BOOST_OBSIDIAN then
	local function BoostObsidianAxe(inst)
		inst.components.weapon:SetDamage(TUNING.AXE_DAMAGE*3)
		inst.components.tool:SetAction(ACTIONS.CHOP, 3)
	end
	local function BoostObsidianMachete(inst)
		inst.components.weapon:SetDamage(TUNING.MACHETE_DAMAGE*3)
		inst.components.tool:SetAction(ACTIONS.HACK, 3)
	end
	local function BoostObsidianSpear(inst)
		inst.components.weapon:SetDamage(TUNING.SPEAR_DAMAGE*3)
	end
	AddPrefabPostInit("obsidianaxe", BoostObsidianAxe)
	AddPrefabPostInit("obsidianmachete", BoostObsidianMachete)
	AddPrefabPostInit("spear_obsidian", BoostObsidianSpear)
end
		
--| Increase boomerang speed |--

if BOOMERANG_SPEED ~= "10" then
	local function BoomerangSpeed(inst)
		inst.components.projectile:SetSpeed(BOOMERANG_SPEED)
	end
	AddPrefabPostInit("boomerang", BoomerangSpeed)
end

--| Increase torch light radius |--

if TORCH_RADIUS then
	RADIUS = 5	--Default: 2 (meters)
	local function IncreaseTorchRadius(inst)
		if inst and inst.Light then
			inst.Light:SetRadius( RADIUS )
		end
	end
	AddPrefabPostInit("torchfire", IncreaseTorchRadius)
end

--| Function to infinitize prefabs and put the item at full capacity |-- 

function RemoveDurability(inst)
		
	inst:AddTag("Infinite") -- For itemtile
	
	-- This will remove the number of uses from prefab.
	
	if inst.components.finiteuses then
		inst.components.finiteuses.Use = function () end
		if inst.components.finiteuses.current < inst.components.finiteuses.total then
			inst.components.finiteuses.current = inst.components.finiteuses.total
		end		
	end
	
	if inst.components.useableitem then
		inst.components.useableitem.StartUsingItem = function () end
	end
	
	-- This will remove prefab degradation over time.
	
	if inst.components.perishable then	
		--inst:RemoveComponent("perishable") 			-- Removing components can cause crashs but it looks ok for perishing
		inst.components.perishable.StartPerishing = function () end
		inst.components.perishable:StopPerishing()			
	end
	--[[
	if inst:HasTag("show_spoilage") then
		inst:RemoveTag("show_spoilage")
	end
	--]]
	-- This will remove prefab fuel usage.
	
	if inst.components.fueled then
		inst.components.fueled.DoDelta = function () end
		inst.components.fueled.StartConsuming = function () end
	end
	
	-- This will make boat invulnerable to attacks, waves and usage.
	
	if inst.components.boathealth then		
		inst.components.boathealth.DoUpdate = function () end
		--inst.components.boathealth.SetHealth = inst.maxhealth
		--inst.components.boathealth:SetInvincible(true)
		inst.components.boathealth.LeakingHealth = 0
		TUNING.WAVE_HIT_DAMAGE = 0
		TUNING.ROGUEWAVE_HIT_DAMAGE = 0		
	end	
	
	-- This makes the wall absorb 100% of dammage, thus not loosing health
	
	if inst.components.health and inst:HasTag("wall") then
		inst.components.health:SetAbsorptionAmount(1)
	end
	
	-- This will prevent armor from loosing durability
	
	AddComponentPostInit("armor", function(self)				
		function Armor:TakeDamage(damage_amount, attacker, weapon)
			if self:CanResist(attacker, weapon) then
				local leftover = damage_amount	
				GoldArmor = {
					goldarmor = false,
							}
				GoldHelm = {
					goldhelm = false,
							}
				ArmorGold = {
					armor_gold = false,
							}
				HatGold = {
					hat_gold = false,
							}
				if GOLD_ITEM_BONUS == "Infinite" then
					if MadMan then
						GoldArmor = {
							goldarmor = true,
							}
						GoldHelm = {
							goldhelm = true,
							}
					end
					if GoldKit then
						ArmorGold = {
							armor_gold = true,
							}
						HatGold = {
							hat_gold = true,
							}
					end
				end
				
				local max_absorbed = damage_amount * self.absorb_percent;
				local absorbed = math.floor(math.min(max_absorbed, self.condition))
				leftover = damage_amount - absorbed
				--ProfileStatsAdd("armor_absorb", absorbed)  -- Removed damage absobtion

				if METRICS_ENABLED then
					FightStat_Absorb(absorbed)
				end					
				if ARMOR_BODY == "Infinite" and not inst:HasTag("hat") then
					--self:SetCondition(self.condition - absorbed) -- Removed damage absobtion
					self:SetCondition(self.maxcondition)						
				elseif GoldArmor[self.inst.prefab] or ArmorGold[self.inst.prefab] then       -- Will affect GoldArmor but no other armors
					self:SetCondition(self.maxcondition)					
				else
					self:SetCondition(self.condition - absorbed)
				end
				if ARMOR_HAT == "Infinite" and inst:HasTag("hat") then
					--self:SetCondition(self.condition - absorbed) -- Removed damage absobtion
					self:SetCondition(self.maxcondition)						
				elseif GoldHelm[self.inst.prefab] or HatGold[self.inst.prefab] then       -- Will affect GoldHat but no other hats
					self:SetCondition(self.maxcondition)					
				else
					self:SetCondition(self.condition - absorbed)
				end
				if self.ontakedamage then
					self.ontakedamage(self.inst, damage_amount, absorbed, leftover)
				end

				if self.absorb_percent >= 1 then
					return 0
				end

				return leftover
			else
				return damage_amount
			end
		end	
	end)		
end

--| Function dedicated to infinite torchs only |--

function InfiniteTorch(inst)
	inst:AddTag("Infinite")
	inst.components.fueled.StartConsuming = function () end
	inst.components.fueled.DoDelta  = function () end
	inst.components.equippable:SetOnEquip( function(inst, owner, force) 	-- Changed the torch's onequip function
		if not owner.sg:HasStateTag("rowing") or force then
			inst.components.burnable:Ignite()
			
			owner.AnimState:OverrideSymbol("swap_object", "swap_torch", "swap_torch")
			owner.AnimState:Show("ARM_carry") 
			owner.AnimState:Hide("ARM_normal") 
			
			inst.SoundEmitter:PlaySound("dontstarve/wilson/torch_LP", "torch")
			inst.SoundEmitter:PlaySound("dontstarve/wilson/torch_swing")
			inst.SoundEmitter:SetParameter( "torch", "intensity", 1 )
			if not inst.fire then 
				inst.fire = SpawnPrefab( "torchfire" )
				local follower = inst.fire.entity:AddFollower()
				follower:FollowSymbol( owner.GUID, "swap_object", 0, -110, 1 )
			end	
																				-- Removed the DoTaskInTime DoDelta
		end
	end)
end

--| This is where user selections are applied to prefabs |--

-- Edit durability of bats --

if BATS ~= "Default" then
	if BATS == "Infinite" then
		AddPrefabPostInit("batbat", RemoveDurability)			
		AddPrefabPostInit("hambat", RemoveDurability)
		AddPrefabPostInit("ruins_bat", RemoveDurability)
		AddPrefabPostInit("tentaclespike", RemoveDurability)
		if PK then
			AddPrefabPostInit("cork_bat", RemoveDurability)
		end
		if MadMan then
			AddPrefabPostInit("houndsbite", RemoveDurability)
		end
		if WoodClub then
			AddPrefabPostInit("wooden_club", RemoveDurability)
		end
		if FightStick then
			AddPrefabPostInit("fightstick", RemoveDurability)
		end
		if SpiderBlade then
			AddPrefabPostInit("scythe", RemoveDurability)
		end
		if SurvivalGear then
			AddPrefabPostInit("punisher", RemoveDurability)
			AddPrefabPostInit("punisher_2", RemoveDurability)
		end
		if Twicane then
			AddPrefabPostInit("twicane", RemoveDurability)
		end
	else
		function EditBats(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * BATS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * BATS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * BATS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * BATS)
			end			
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * BATS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * BATS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * BATS)       
			end 
		end
		AddPrefabPostInit("batbat", EditBats)			
		AddPrefabPostInit("hambat", EditBats)
		AddPrefabPostInit("ruins_bat", EditBats)
		AddPrefabPostInit("tentaclespike", EditBats)
		if PK then
			AddPrefabPostInit("cork_bat", EditBats)
		end
		if MadMan then
			AddPrefabPostInit("houndsbite", EditBats)
		end
		if WoodClub then
			AddPrefabPostInit("wooden_club", EditBats)
		end
		if FightStick then
			AddPrefabPostInit("fightstick", EditBats)
		end
		if SpiderBlade then
			AddPrefabPostInit("scythe", EditBats)
		end
		if SurvivalGear then
			AddPrefabPostInit("punisher", EditBats)
			AddPrefabPostInit("punisher_2", EditBats)
		end
		if Twicane then
			AddPrefabPostInit("twicane", EditBats)
		end
	end
end

-- Edit durability of spears --

if SPEARS ~= "Default" then
	if SPEARS == "Infinite" then
		AddPrefabPostInit("spear", RemoveDurability)
		if ROG or SW or PK then
			AddPrefabPostInit("spear_wathgrithr", RemoveDurability)
		end
		if SW or PK then
			AddPrefabPostInit("harpoon", RemoveDurability)
			AddPrefabPostInit("needlespear", RemoveDurability)
			AddPrefabPostInit("peg_leg", RemoveDurability)
			AddPrefabPostInit("spear_launcher", RemoveDurability)
			AddPrefabPostInit("spear_obsidian", RemoveDurability)
			AddPrefabPostInit("spear_poison", RemoveDurability)				
			AddPrefabPostInit("trident", RemoveDurability)
		end
		if EtherealSpear then
			AddPrefabPostInit("ethrl_spear", RemoveDurability)
		end
		if GoldSpear then
			AddPrefabPostInit("goldenspear", RemoveDurability)
		end
	else
		function EditSpears(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * SPEARS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * SPEARS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * SPEARS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * SPEARS)
			end			
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * SPEARS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * SPEARS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * SPEARS)       
			end 
		end
		AddPrefabPostInit("spear", EditSpears)
		if ROG or SW or PK then
			AddPrefabPostInit("spear_wathgrithr", EditSpears)
		end
		if SW or PK then
			AddPrefabPostInit("harpoon", EditSpears)
			AddPrefabPostInit("needlespear", EditSpears)
			AddPrefabPostInit("peg_leg", EditSpears)
			AddPrefabPostInit("spear_launcher", EditSpears)
			AddPrefabPostInit("spear_obsidian", EditSpears)
			AddPrefabPostInit("spear_poison", EditSpears)				
			AddPrefabPostInit("trident", EditSpears)
		end			
		if OBSIDIAN_DURABILITY == "Default" then
				AddPrefabPostInit("spear_obsidian", EditSpears)
			end
		if EtherealSpear then
			AddPrefabPostInit("ethrl_spear", EditSpears)
		end
		if GoldSpear then
			if GOLD_DURABILITY == "Default" then
				AddPrefabPostInit("goldenspear", EditSpears)
			end
		end
	end
end

-- Edit durability of swords --

if SWORDS ~= "Default" then
	if SWORDS == "Infinite" then
		AddPrefabPostInit("nightsword", RemoveDurability)
		if ROG or SW or PK then
			AddPrefabPostInit("nightstick", RemoveDurability)
		end
		if SW or PK then			
			AddPrefabPostInit("cutlass", RemoveDurability)
		end
		if PK then
			AddPrefabPostInit("halberd", RemoveDurability)
		end
		if MadMan then
			AddPrefabPostInit("goldsword", RemoveDurability)				
			AddPrefabPostInit("nightsword", RemoveDurability)				
			AddPrefabPostInit("strongsword", RemoveDurability)
			AddPrefabPostInit("marbleblade", RemoveDurability)
			AddPrefabPostInit("iceblade", RemoveDurability)	
		end
		if GoldKit then
			AddPrefabPostInit("sword_gold", RemoveDurability)
		end
		if FishSword then
			AddPrefabPostInit("fishsword", RemoveDurability)
		end
		if Sword then
			AddPrefabPostInit("sword", RemoveDurability)
		end
		if Claymore then
			AddPrefabPostInit("claymore_gray", RemoveDurability)
		end
		if LinkSword then
			AddPrefabPostInit("linksword", RemoveDurability)
		end
		if AdventureItems then
			AddPrefabPostInit("adventure_sword", RemoveDurability)
			AddPrefabPostInit("demon_sword", RemoveDurability)
			AddPrefabPostInit("finn_sword", RemoveDurability)
			AddPrefabPostInit("axe_brass", RemoveDurability)
		end
		if Zorce then
			AddPrefabPostInit("goldsword", RemoveDurability)
			AddPrefabPostInit("stonesword", RemoveDurability)
		end
	else
		function EditSwords(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * SWORDS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * SWORDS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * SWORDS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * SWORDS)
			end			
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * SWORDS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * SWORDS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * SWORDS)       
			end 
		end
		AddPrefabPostInit("nightsword", EditSwords)
		if ROG or SW or PK then
			AddPrefabPostInit("nightstick", EditSwords)
		end
		if SW or PK then
			AddPrefabPostInit("cutlass", EditSwords)
		end
		if PK then
			AddPrefabPostInit("halberd", EditSwords)
		end
		if MadMan then			
			if GOLD_DURABILITY == "Default" then
				AddPrefabPostInit("goldsword", EditSwords)
			end
			AddPrefabPostInit("strongsword", EditSwords)
			AddPrefabPostInit("marbleblade", EditSwords)
			AddPrefabPostInit("iceblade", EditSwords)
		end
		if GoldKit then
			if GOLD_DURABILITY == "Default" then
				AddPrefabPostInit("sword_gold", EditSwords)
			end
		end
		if FishSword then
			AddPrefabPostInit("fishsword", EditSwords)
		end
		if Sword then
			AddPrefabPostInit("sword", EditSwords)
		end
		if Claymore then
			AddPrefabPostInit("claymore_gray", EditSwords)
		end
		if LinkSword then
			AddPrefabPostInit("linksword", EditSwords)
		end
		if AdventureItems then
			AddPrefabPostInit("adventure_sword", EditSwords)
			AddPrefabPostInit("demon_sword", EditSwords)
			AddPrefabPostInit("finn_sword", EditSwords)
			AddPrefabPostInit("axe_brass", EditSwords)
		end
		if Zorce then
			if GOLD_DURABILITY == "Default" then
				AddPrefabPostInit("goldsword", EditSwords)
			end
			AddPrefabPostInit("stonesword", EditSwords)				
		end
	end
end

-- Edit durability of boomerang --

if BOOMERANG ~= "Default" then
	if BOOMERANG == "Infinite" then		
		AddPrefabPostInit("boomerang", RemoveDurability)
	else			
		function EditBoomerang(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * BOOMERANG)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * BOOMERANG)
			end	
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * BOOMERANG)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * BOOMERANG)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * BOOMERANG)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * BOOMERANG)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * BOOMERANG)       
			end 
		end
		AddPrefabPostInit("boomerang", EditBoomerang)
	end
end

-- Edit durability of body armors --

if ARMOR_BODY ~= "Default" then
	if ARMOR_BODY == "Infinite" then
		AddPrefabPostInit("armorgrass", RemoveDurability)
		AddPrefabPostInit("armormarble", RemoveDurability)
		AddPrefabPostInit("armorruins", RemoveDurability)
		AddPrefabPostInit("armor_sanity", RemoveDurability)
		AddPrefabPostInit("armorsnurtleshell", RemoveDurability)
		AddPrefabPostInit("armorwood", RemoveDurability)	
		if ROG or SW then
			AddPrefabPostInit("wathgrithrhat", RemoveDurability)
		end
		if SW or PK then
			AddPrefabPostInit("armorcactus", RemoveDurability)
			AddPrefabPostInit("armorlimestone", RemoveDurability)
			AddPrefabPostInit("armorobsidian", RemoveDurability)
			AddPrefabPostInit("armorseashell", RemoveDurability)  -- Already dont have anything to remove
		end	
		if PK then
			AddPrefabPostInit("armor_metalplate", RemoveDurability)
			AddPrefabPostInit("armor_weevole", RemoveDurability)
			AddPrefabPostInit("antsuit", RemoveDurability)
		end
		if MadMan then
			AddPrefabPostInit("goldarmor", RemoveDurability)
		end
		if GoldKit then
			AddPrefabPostInit("armor_gold", RemoveDurability)
		end
		if FishArmor then
			AddPrefabPostInit("armor_my", RemoveDurability)
		end
	else			
		function EditBodyArmors(inst)
			inst.components.armor.condition = (inst.components.armor.condition * ARMOR_BODY)
			inst.components.armor.maxcondition = (inst.components.armor.maxcondition * ARMOR_BODY)
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * ARMOR_BODY)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * ARMOR_BODY)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * ARMOR_BODY)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * ARMOR_BODY)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * ARMOR_BODY)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * ARMOR_BODY)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * ARMOR_BODY)       
			end 
		end
		AddPrefabPostInit("armorgrass", EditBodyArmors)
		AddPrefabPostInit("armormarble", EditBodyArmors)
		AddPrefabPostInit("armorruins", EditBodyArmors)
		AddPrefabPostInit("armor_sanity", EditBodyArmors)
		AddPrefabPostInit("armorsnurtleshell", EditBodyArmors)
		AddPrefabPostInit("armorwood", EditBodyArmors)		
		if ROG or SW or PK then
			AddPrefabPostInit("armordragonfly", EditBodyArmors)
		end
		if SW or PK then
			AddPrefabPostInit("armorcactus", EditBodyArmors)
			AddPrefabPostInit("armorlimestone", EditBodyArmors)
			AddPrefabPostInit("armorobsidian", EditBodyArmors)
			AddPrefabPostInit("armorseashell", EditBodyArmors)  -- Already dont have anything to remove
		end	
		if PK then
			AddPrefabPostInit("armor_metalplate", EditBodyArmors)
			AddPrefabPostInit("armor_weevole", EditBodyArmors)
			AddPrefabPostInit("antsuit", EditBodyArmors)
		end
		if MadMan then
			if GOLD_DURABILITY == "Default" then
				AddPrefabPostInit("goldarmor", EditBodyArmors)
			end
		end
		if GoldKit then
			if GOLD_DURABILITY == "Default" then
				AddPrefabPostInit("armor_gold", EditBodyArmors)
			end
		end
		if FishArmor then
			AddPrefabPostInit("armor_my", EditBodyArmors)
		end
	end
end

-- Edit durability of hat armors --

if ARMOR_HAT ~= "Default" then
	if ARMOR_HAT == "Infinite" then
		AddPrefabPostInit("beehat", RemoveDurability)
		AddPrefabPostInit("footballhat", RemoveDurability)
		AddPrefabPostInit("slurtlehat", RemoveDurability)
		AddPrefabPostInit("ruinshat", RemoveDurability)			
		if ROG or SW or PK then
			AddPrefabPostInit("wathgrithrhat", RemoveDurability)
		end
		if SW or PK then
			AddPrefabPostInit("oxhat", RemoveDurability)
		end	
		if PK then
			AddPrefabPostInit("antmaskhat", RemoveDurability)
			AddPrefabPostInit("metalplatehat", RemoveDurability)
		end
		if MadMan then
			AddPrefabPostInit("goldhelm", RemoveDurability)
		end
		if GoldKit then
			AddPrefabPostInit("hat_gold", RemoveDurability)
		end
		if FishHat then
			AddPrefabPostInit("fishbrella", RemoveDurability)
		end
		if AdventureItems then
			AddPrefabPostInit("ik_crown", RemoveDurability)
			AddPrefabPostInit("pb_crown", RemoveDurability)
		end
	else			
		function EditHatArmors(inst)
			inst.components.armor.condition = (inst.components.armor.condition * ARMOR_HAT)
			inst.components.armor.maxcondition = (inst.components.armor.maxcondition * ARMOR_HAT)
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * ARMOR_HAT)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * ARMOR_HAT)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * ARMOR_HAT)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * ARMOR_HAT)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * ARMOR_HAT)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * ARMOR_HAT)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * ARMOR_HAT)       
			end 
		end
		AddPrefabPostInit("beehat", EditHatArmors)
		AddPrefabPostInit("footballhat", EditHatArmors)
		AddPrefabPostInit("slurtlehat", EditHatArmors)
		AddPrefabPostInit("ruinshat", EditHatArmors)			
		if ROG or SW or PK then
			AddPrefabPostInit("wathgrithrhat", EditHatArmors)
		end
		if SW or PK then
			AddPrefabPostInit("oxhat", EditHatArmors)
		end	
		if PK then
			AddPrefabPostInit("antmaskhat", EditHatArmors)
			AddPrefabPostInit("metalplatehat", EditHatArmors)
		end
		if MadMan then
			if GOLD_DURABILITY == "Default" then
				AddPrefabPostInit("goldhelm", EditHatArmors)
			end
		end
		if GoldKit then
			if GOLD_DURABILITY == "Default" then
				AddPrefabPostInit("hat_gold", EditHatArmors)
			end
		end
		if FishHat then
			AddPrefabPostInit("fishbrella", EditHatArmors)
		end
		if AdventureItems then
			AddPrefabPostInit("ik_crown", EditHatArmors)
			AddPrefabPostInit("pb_crown", EditHatArmors)
		end
	end
end

-- Edit durability of staffs --

if STAFFS ~= "Default" then
	if STAFFS == "Infinite" then
		AddPrefabPostInit("icestaff", RemoveDurability)
		AddPrefabPostInit("firestaff", RemoveDurability)
		AddPrefabPostInit("telestaff", RemoveDurability)
		AddPrefabPostInit("orangestaff", RemoveDurability)
		AddPrefabPostInit("greenstaff", RemoveDurability)			
		AddPrefabPostInit("yellowstaff", RemoveDurability)
		if ROG or SW then
			AddPrefabPostInit("staff_tornado", RemoveDurability)
		end
		if SW then
			AddPrefabPostInit("volcanostaff", RemoveDurability)
			AddPrefabPostInit("sail_stick", RemoveDurability)
		end
	else			
		function EditStaffs(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * STAFFS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * STAFFS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * STAFFS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * STAFFS)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * STAFFS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * STAFFS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * STAFFS)       
			end 
		end
		AddPrefabPostInit("icestaff", EditStaffs)
		AddPrefabPostInit("firestaff", EditStaffs)
		AddPrefabPostInit("telestaff", EditStaffs)
		AddPrefabPostInit("orangestaff", EditStaffs)
		AddPrefabPostInit("greenstaff", EditStaffs)			
		AddPrefabPostInit("yellowstaff", EditStaffs)
		if ROG or SW then
			AddPrefabPostInit("staff_tornado", EditStaffs)
		end
		if SW then
			AddPrefabPostInit("volcanostaff", EditStaffs)
			AddPrefabPostInit("sail_stick", EditStaffs)
		end
	end
end

-- Edit durability of amulets --

if AMULETS ~= "Default" then
	if AMULETS == "Infinite" then		
		AddPrefabPostInit("amulet", RemoveDurability)
		AddPrefabPostInit("blueamulet", RemoveDurability)
		AddPrefabPostInit("purpleamulet", RemoveDurability)
		AddPrefabPostInit("orangeamulet", RemoveDurability)
		AddPrefabPostInit("greenamulet", RemoveDurability)
		AddPrefabPostInit("yellowamulet", RemoveDurability)			
	else			
		function EditAmulets(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * AMULETS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * AMULETS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * AMULETS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * AMULETS)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * AMULETS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * AMULETS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * AMULETS)       
			end 
		end		
		AddPrefabPostInit("amulet", EditAmulets)
		AddPrefabPostInit("blueamulet", EditAmulets)
		AddPrefabPostInit("purpleamulet", EditAmulets)
		AddPrefabPostInit("orangeamulet", EditAmulets)
		AddPrefabPostInit("greenamulet", EditAmulets)
		AddPrefabPostInit("yellowamulet", EditAmulets)			
	end
end

-- Edit durability of survival tools --

if SURVIVAL_TOOLS ~= "Default" then
	if SURVIVAL_TOOLS == "Infinite" then
		AddPrefabPostInit("bugnet", RemoveDurability)
		AddPrefabPostInit("fishingrod", RemoveDurability)
		AddPrefabPostInit("horn", RemoveDurability)
		AddPrefabPostInit("onemanband", RemoveDurability)
		AddPrefabPostInit("panflute", RemoveDurability)
		if ROG or SW or PK then
			AddPrefabPostInit("bell", RemoveDurability)		-- prefab name gloomerbell
			AddPrefabPostInit("featherfan", RemoveDurability)
			AddPrefabPostInit("fertilizer", RemoveDurability)
			AddPrefabPostInit("firesuppressor", RemoveDurability)				
		end
		if SW or PK then
			AddPrefabPostInit("ox_flute", RemoveDurability)
			AddPrefabPostInit("ox_horn", RemoveDurability)
			AddPrefabPostInit("tropicalfan", RemoveDurability)		-- Same file as featherfan
			AddPrefabPostInit("monkeyball", RemoveDurability)
			AddPrefabPostInit("wind_conch", RemoveDurability)
		end	
		if PK then
			AddPrefabPostInit("disarming_kit", RemoveDurability)
			AddPrefabPostInit("goldpan", RemoveDurability)
			AddPrefabPostInit("magnifying_glass", RemoveDurability)
			AddPrefabPostInit("bugrepellent", RemoveDurability)
			AddPrefabPostInit("sprinkler", RemoveDurability)
			AddPrefabPostInit("basefan", RemoveDurability)
		end
		if MineMachine then
			AddPrefabPostInit("wrench", RemoveDurability)
		end
	else			
		function EditSurvivalTools(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * SURVIVAL_TOOLS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * SURVIVAL_TOOLS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * SURVIVAL_TOOLS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * SURVIVAL_TOOLS)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * SURVIVAL_TOOLS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * SURVIVAL_TOOLS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * SURVIVAL_TOOLS)       
			end 
		end
		AddPrefabPostInit("bugnet", EditSurvivalTools)
		AddPrefabPostInit("fishingrod", EditSurvivalTools)
		AddPrefabPostInit("horn", EditSurvivalTools)
		AddPrefabPostInit("onemanband", EditSurvivalTools)
		AddPrefabPostInit("panflute", EditSurvivalTools)
		
		if ROG or SW or PK then
			AddPrefabPostInit("bell", EditSurvivalTools)		-- prefab name gloomerbell
			AddPrefabPostInit("featherfan", EditSurvivalTools)
			AddPrefabPostInit("fertilizer", EditSurvivalTools)
			AddPrefabPostInit("firesuppressor", EditSurvivalTools)
		end
		if SW or PK then
			AddPrefabPostInit("ox_flute", EditSurvivalTools)
			AddPrefabPostInit("ox_horn", EditSurvivalTools)
			AddPrefabPostInit("tropicalfan", EditSurvivalTools)		-- Same file as featherfan
			AddPrefabPostInit("monkeyball", EditSurvivalTools)
			AddPrefabPostInit("wind_conch", EditSurvivalTools)
		end	
		if PK then
			AddPrefabPostInit("disarming_kit", EditSurvivalTools)
			AddPrefabPostInit("goldpan", EditSurvivalTools)
			AddPrefabPostInit("magnifying_glass", EditSurvivalTools)
			AddPrefabPostInit("bugrepellent", EditSurvivalTools)
			AddPrefabPostInit("sprinkler", EditSurvivalTools)
			AddPrefabPostInit("basefan", EditSurvivalTools)
		end
		if MineMachine then
			AddPrefabPostInit("wrench", EditSurvivalTools)
		end
	end
end

-- Edit durability of sewingkit --

if SEWINGKIT ~= "Default" then
	if SEWINGKIT == "Infinite" then		
		AddPrefabPostInit("sewing_kit", RemoveDurability)
	else			
		function EditSewingKit(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * SEWINGKIT)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * SEWINGKIT)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * SEWINGKIT)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * SEWINGKIT)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * SEWINGKIT)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * SEWINGKIT)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * SEWINGKIT)       
			end 
		end
		AddPrefabPostInit("sewing_kit", EditSewingKit)
	end
end

-- Edit durability of compass --

if COMPASS ~= "Default" then
	if COMPASS == "Infinite" then		
		AddPrefabPostInit("compass", RemoveDurability)
	else			
		function EditCompass(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * COMPASS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * COMPASS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * COMPASS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * COMPASS)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * COMPASS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * COMPASS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * COMPASS)       
			end 
		end
		AddPrefabPostInit("compass", EditCompass)
	end
end

-- Edit durability of primary tools --

if PRIMARY_TOOLS ~= "Default" then
	if PRIMARY_TOOLS == "Infinite" then		
		AddPrefabPostInit("axe", RemoveDurability)
		AddPrefabPostInit("goldenaxe", RemoveDurability)
		AddPrefabPostInit("hammer", RemoveDurability)			
		AddPrefabPostInit("pickaxe", RemoveDurability)
		AddPrefabPostInit("goldenpickaxe", RemoveDurability)
		AddPrefabPostInit("pitchfork", RemoveDurability)
		AddPrefabPostInit("shovel", RemoveDurability)
		AddPrefabPostInit("goldenshovel", RemoveDurability)		
		AddPrefabPostInit("multitool_axe_pickaxe", RemoveDurability)		
		if SW or PK then
			AddPrefabPostInit("obsidianaxe", RemoveDurability)
			AddPrefabPostInit("machete", RemoveDurability)
			AddPrefabPostInit("goldenmachete", RemoveDurability)
			AddPrefabPostInit("obsidianmachete", RemoveDurability)				
		end
		if PK then
			AddPrefabPostInit("shears", RemoveDurability)
			AddPrefabPostInit("ballpein_hammer", RemoveDurability)
		end
		if Scythe then
			AddPrefabPostInit("scythe", RemoveDurability)
		end
	else			
		function EditPrimaryTools(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * PRIMARY_TOOLS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * PRIMARY_TOOLS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * PRIMARY_TOOLS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * PRIMARY_TOOLS)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * PRIMARY_TOOLS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * PRIMARY_TOOLS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * PRIMARY_TOOLS)       
			end 
		end
		AddPrefabPostInit("axe", EditPrimaryTools)
		AddPrefabPostInit("goldenaxe", EditPrimaryTools)
		AddPrefabPostInit("hammer", EditPrimaryTools)
		AddPrefabPostInit("pickaxe", EditPrimaryTools)
		AddPrefabPostInit("goldenpickaxe", EditPrimaryTools)
		AddPrefabPostInit("pitchfork", EditPrimaryTools)
		AddPrefabPostInit("shovel", EditPrimaryTools)
		AddPrefabPostInit("goldenshovel", EditPrimaryTools)		
		AddPrefabPostInit("multitool_axe_pickaxe", EditPrimaryTools)		
		if SW or PK then
			AddPrefabPostInit("obsidianaxe", EditPrimaryTools)
			AddPrefabPostInit("machete", EditPrimaryTools)
			AddPrefabPostInit("goldenmachete", EditPrimaryTools)
			AddPrefabPostInit("obsidianmachete", EditPrimaryTools)
		end		
		if PK then
			AddPrefabPostInit("shears", EditPrimaryTools)
			AddPrefabPostInit("ballpein_hammer", EditPrimaryTools)
		end
		if Scythe then
			AddPrefabPostInit("scythe", EditPrimaryTools)
		end
	end
end

-- Edit durability of gold items --

if GOLD_ITEM_BONUS ~= "Default" then
	if GOLD_ITEM_BONUS == "Infinite" then			
		AddPrefabPostInit("goldenaxe", RemoveDurability)
		AddPrefabPostInit("goldenpickaxe", RemoveDurability)
		AddPrefabPostInit("goldenshovel", RemoveDurability)
		if SW then
			AddPrefabPostInit("goldenmachete", RemoveDurability)
		end
		if MadMan then
			AddPrefabPostInit("goldsword", RemoveDurability)
			AddPrefabPostInit("goldarmor", RemoveDurability)
			AddPrefabPostInit("goldhelm", RemoveDurability)
		end
		if GoldKit then
			AddPrefabPostInit("sword_gold", RemoveDurability)
			AddPrefabPostInit("armor_gold", RemoveDurability)
			AddPrefabPostInit("hat_gold", RemoveDurability)				
		end
		if GoldHammer then
			AddPrefabPostInit("goldhammer", RemoveDurability)
		end
		if Scythe then
			AddPrefabPostInit("golden_scythe", RemoveDurability)
		end
		if Zorce then				
			AddPrefabPostInit("goldsword", RemoveDurability)
		end
	else			
		function EditGoldItems(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * GOLD_ITEM_BONUS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * GOLD_ITEM_BONUS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * GOLD_ITEM_BONUS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * GOLD_ITEM_BONUS)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * GOLD_ITEM_BONUS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * GOLD_ITEM_BONUS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * GOLD_ITEM_BONUS)       
			end 
		end
		function SpearInterference(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * GOLD_ITEM_BONUS * SPEARS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * GOLD_ITEM_BONUS * SPEARS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * GOLD_ITEM_BONUS * SPEARS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * GOLD_ITEM_BONUS * SPEARS)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * GOLD_ITEM_BONUS * SPEARS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * GOLD_ITEM_BONUS * SPEARS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * GOLD_ITEM_BONUS * SPEARS)       
			end 
		end
		function SwordInterference(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * GOLD_ITEM_BONUS * SWORDS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * GOLD_ITEM_BONUS * SWORDS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * GOLD_ITEM_BONUS * SWORDS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * GOLD_ITEM_BONUS * SWORDS)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * GOLD_ITEM_BONUS * SWORDS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * GOLD_ITEM_BONUS * SWORDS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * GOLD_ITEM_BONUS * SWORDS)       
			end 
		end
		function ToolInterferenceGold(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * GOLD_ITEM_BONUS * PRIMARY_TOOLS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * GOLD_ITEM_BONUS * PRIMARY_TOOLS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * GOLD_ITEM_BONUS * PRIMARY_TOOLS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * GOLD_ITEM_BONUS * PRIMARY_TOOLS)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * GOLD_ITEM_BONUS * PRIMARY_TOOLS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * GOLD_ITEM_BONUS * PRIMARY_TOOLS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * GOLD_ITEM_BONUS * PRIMARY_TOOLS)       
			end 
		end
		function BodyArmorInterference(inst)
			inst.components.armor.condition = (inst.components.armor.condition * GOLD_ITEM_BONUS * ARMOR_BODY)
			inst.components.armor.maxcondition = (inst.components.armor.maxcondition * GOLD_ITEM_BONUS * ARMOR_BODY)
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * GOLD_ITEM_BONUS * ARMOR_BODY)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * GOLD_ITEM_BONUS * ARMOR_BODY)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * GOLD_ITEM_BONUS * ARMOR_BODY)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * GOLD_ITEM_BONUS * ARMOR_BODY)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * GOLD_ITEM_BONUS * ARMOR_BODY)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * GOLD_ITEM_BONUS * ARMOR_BODY)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * GOLD_ITEM_BONUS * ARMOR_BODY)       
			end 
		end
		function HatArmorInterference(inst)
			inst.components.armor.condition = (inst.components.armor.condition * GOLD_ITEM_BONUS * ARMOR_HAT)
			inst.components.armor.maxcondition = (inst.components.armor.maxcondition * GOLD_ITEM_BONUS * ARMOR_HAT)
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * GOLD_ITEM_BONUS * ARMOR_HAT)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * GOLD_ITEM_BONUS * ARMOR_HAT)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * GOLD_ITEM_BONUS * ARMOR_HAT)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * GOLD_ITEM_BONUS * ARMOR_HAT)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * GOLD_ITEM_BONUS * ARMOR_HAT)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * GOLD_ITEM_BONUS * ARMOR_HAT)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * GOLD_ITEM_BONUS * ARMOR_HAT)       
			end 
		end
		if PRIMARY_TOOLS ~= "Default" then
			if PRIMARY_TOOLS ~= "Infinite" then
				AddPrefabPostInit("goldenaxe", ToolInterferenceGold)
				AddPrefabPostInit("goldenpickaxe", ToolInterferenceGold)
				AddPrefabPostInit("goldenshovel", ToolInterferenceGold)	
				if SW then
					AddPrefabPostInit("goldenmachete", ToolInterferenceGold)
				end
			end
		else
			AddPrefabPostInit("goldenaxe", EditGoldItems)
			AddPrefabPostInit("goldenpickaxe", EditGoldItems)
			AddPrefabPostInit("goldenshovel", EditGoldItems)
			if SW then
				AddPrefabPostInit("goldenmachete", ToolInterferenceGold)
			end
		end			
		if MadMan then
			if SWORDS ~= "Default" then
				if SWORDS ~= "Infinite" then
					AddPrefabPostInit("goldsword", SwordInterference)						
				end
			else
				AddPrefabPostInit("goldsword", EditGoldItems)					
			end
			if ARMOR_BODY ~= "Default" then
				if ARMOR_BODY ~= "Infinite" then
					AddPrefabPostInit("goldarmor", BodyArmorInterference)
				end
			else
				AddPrefabPostInit("goldarmor", EditGoldItems)
			end
			if ARMOR_HAT ~= "Default" then
				if ARMOR_HAT ~= "Infinite" then
					AddPrefabPostInit("goldhelm", HatArmorInterference)
				end
			else
				AddPrefabPostInit("goldhelm", EditGoldItems)
			end
		end
		if GoldKit then
			if SWORDS ~= "Default" then
				if SWORDS ~= "Infinite" then
					AddPrefabPostInit("sword_gold", SwordInterference)
				end
			else
				AddPrefabPostInit("sword_gold", EditGoldItems)					
			end
			if ARMOR_BODY ~= "Default" then
				if ARMOR_BODY ~= "Infinite" then
					AddPrefabPostInit("armor_gold", BodyArmorInterference)
				end
			else
				AddPrefabPostInit("armor_gold", EditGoldItems)
			end
			if ARMOR_HAT ~= "Default" then
				if ARMOR_HAT ~= "Infinite" then
					AddPrefabPostInit("hat_gold", HatArmorInterference)
				end
			else
				AddPrefabPostInit("hat_gold", EditGoldItems)
			end
		end
		if GoldHammer then				
			AddPrefabPostInit("goldhammer", EditGoldItems)				
		end
		if Scythe then
			if PRIMARY_TOOLS ~= "Default" then
				if PRIMARY_TOOLS ~= "Infinite" then
					AddPrefabPostInit("golden_scythe", ToolInterferenceGold)
				end
			else
				AddPrefabPostInit("golden_scythe", EditGoldItems)
			end
		end
		if Zorce then
			if SWORDS ~= "Default" then
				if SWORDS ~= "Infinite" then
					AddPrefabPostInit("goldsword", SwordInterference)
				end
			else
				AddPrefabPostInit("goldsword", EditGoldItems)
			end
		end
		if GoldSpear then
			if SPEARS ~= "Default" then
				if SPEARS ~= "Infinite" then
					AddPrefabPostInit("goldenspear", SpearInterference)
				end
			else
				AddPrefabPostInit("goldenspear", EditGoldItems)
			end
		end
	end
end

-- Edit durability of traps --

if TRAPS ~= "Default" then
	if TRAPS == "Infinite" then		
		AddPrefabPostInit("birdtrap", RemoveDurability)
		AddPrefabPostInit("trap", RemoveDurability)			
		if SW == false or (ROG and SW) then
			AddPrefabPostInit("trap_teeth", RemoveDurability)
		end
		if SW then
			AddPrefabPostInit("seatrap", RemoveDurability)
		end
	else			
		function EditTraps(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * TRAPS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * TRAPS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * TRAPS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * TRAPS)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * TRAPS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * TRAPS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * TRAPS)       
			end 
		end
		AddPrefabPostInit("birdtrap", EditTraps)
		AddPrefabPostInit("trap", EditTraps)
		if SW == false or (ROG and SW) then
			AddPrefabPostInit("trap_teeth", EditTraps)
		end
		if SW then
			AddPrefabPostInit("seatrap", EditTraps)
		end
	end
end

-- Edit durability of heatrock --

if HEATROCK ~= "Default" then
	if HEATROCK == "Infinite" then
		local function InfiniteHeatrock(inst)
			applyhealthdelta = false							-- Obvious
		end
		AddComponentPostInit("temperature", InfiniteHeatrock)
	else			
		local function EditHeatrock(inst)
			self.inst.components.health:DoDelta(-self.hurtrate*dt / HEATROCK, true, "cold")
		end
		AddComponentPostInit("temperature", EditHeatrock)
	end
end

-- Edit durability of cloths --

if CLOTHS ~= "Default" then
	if CLOTHS == "Infinite" then
		AddPrefabPostInit("armorslurper", RemoveDurability)
		if ROG or SW or PK then
			AddPrefabPostInit("beargervest", RemoveDurability)				
			AddPrefabPostInit("hawaiianshirt", RemoveDurability)
			AddPrefabPostInit("raincoat", RemoveDurability)
			AddPrefabPostInit("reflectivevest", RemoveDurability)
			AddPrefabPostInit("sweatervest", RemoveDurability)
			AddPrefabPostInit("trunkvest_summer", RemoveDurability)
			AddPrefabPostInit("trunkvest_winter", RemoveDurability)
		end
		if SW or PK then
			AddPrefabPostInit("armor_snakeskin", RemoveDurability)
			AddPrefabPostInit("armor_windbreaker", RemoveDurability)
			AddPrefabPostInit("blubbersuit", RemoveDurability)
		end
		if FishHat then
			AddPrefabPostInit("fishbrella", RemoveDurability)
		end
	else			
		function EditCloths(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * CLOTHS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * CLOTHS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * CLOTHS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * CLOTHS)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * CLOTHS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * CLOTHS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * CLOTHS)       
			end 
		end
		AddPrefabPostInit("armorslurper", TweakCloth)		
		
		AddPrefabPostInit("sweatervest", TweakCloth)
		AddPrefabPostInit("trunkvest_summer", TweakCloth)
		AddPrefabPostInit("trunkvest_winter", TweakCloth)
		if ROG or SW or PK then
			AddPrefabPostInit("beargervest", TweakCloth)				
			AddPrefabPostInit("hawaiianshirt", TweakCloth)
			AddPrefabPostInit("raincoat", TweakCloth)
			AddPrefabPostInit("reflectivevest", TweakCloth)
		end
		if SW or PK then
			AddPrefabPostInit("armor_snakeskin", TweakCloth)
			AddPrefabPostInit("armor_windbreaker", TweakCloth)
			AddPrefabPostInit("blubbersuit", TweakCloth)
		end						
		if FishHat then
			AddPrefabPostInit("fishbrella", TweakCloth)
		end
	end
end

-- Edit durability of hats --

if HATS ~= "Default" then
	if HATS == "Infinite" then
		AddPrefabPostInit("armorslurper", RemoveDurability)		
		AddPrefabPostInit("strawhat", RemoveDurability)
		AddPrefabPostInit("tophat", RemoveDurability)
		AddPrefabPostInit("beefalohat", RemoveDurability)
		AddPrefabPostInit("featherhat", RemoveDurability)
		AddPrefabPostInit("spiderhat", RemoveDurability)
		AddPrefabPostInit("earmuffshat", RemoveDurability)
		AddPrefabPostInit("winterhat", RemoveDurability)
		AddPrefabPostInit("bushhat", RemoveDurability)
		AddPrefabPostInit("flowerhat", RemoveDurability)
		AddPrefabPostInit("walrushat", RemoveDurability)
		if ROG or SW or PK then
			AddPrefabPostInit("icehat", RemoveDurability)
			AddPrefabPostInit("molehat", RemoveDurability)
			AddPrefabPostInit("rainhat", RemoveDurability)
			AddPrefabPostInit("catcoonhat", RemoveDurability)
			AddPrefabPostInit("watermelonhat", RemoveDurability)
			AddPrefabPostInit("eyebrellahat", RemoveDurability)
		end
		if SW or PK then
			AddPrefabPostInit("armor_snakeskin", RemoveDurability)
			AddPrefabPostInit("armor_windbreaker", RemoveDurability)
			AddPrefabPostInit("blubbersuit", RemoveDurability)			
			AddPrefabPostInit("captainhat", RemoveDurability)
			AddPrefabPostInit("snakeskinhat", RemoveDurability)
			AddPrefabPostInit("piratehat", RemoveDurability)
			AddPrefabPostInit("gashat", RemoveDurability)
			AddPrefabPostInit("aerodynamichat", RemoveDurability)
			AddPrefabPostInit("double_umbrellahat", RemoveDurability)
			AddPrefabPostInit("shark_teethhat", RemoveDurability)
			AddPrefabPostInit("brainjellyhat", RemoveDurability)
			AddPrefabPostInit("woodlegshat", RemoveDurability)
		end
		if PK then
			AddPrefabPostInit("peagawkfeatherhat", RemoveDurability)
			AddPrefabPostInit("gasmaskhat", RemoveDurability)
			AddPrefabPostInit("pithhat", RemoveDurability)
			AddPrefabPostInit("bandithat", RemoveDurability)
			AddPrefabPostInit("thunderhat", RemoveDurability)
			AddPrefabPostInit("hayfeverhat", RemoveDurability)
		end
		if FishHat then
			AddPrefabPostInit("fishbrella", RemoveDurability)
		end
	else			
		function EditHats(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * HATS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * HATS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * HATS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * HATS)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * HATS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * HATS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * HATS)       
			end 
		end
		AddPrefabPostInit("strawhat", EditHats)
		AddPrefabPostInit("tophat", EditHats)
		AddPrefabPostInit("beefalohat", EditHats)
		AddPrefabPostInit("featherhat", EditHats)
		AddPrefabPostInit("spiderhat", EditHats)
		AddPrefabPostInit("earmuffshat", EditHats)
		AddPrefabPostInit("winterhat", EditHats)
		AddPrefabPostInit("bushhat", EditHats)
		AddPrefabPostInit("flowerhat", EditHats)
		AddPrefabPostInit("walrushat", EditHats)
		if ROG or SW or PK then
			AddPrefabPostInit("icehat", EditHats)
			AddPrefabPostInit("molehat", EditHats)
			AddPrefabPostInit("rainhat", EditHats)
			AddPrefabPostInit("catcoonhat", EditHats)
			AddPrefabPostInit("watermelonhat", EditHats)
			AddPrefabPostInit("eyebrellahat", EditHats)
		end
		if SW or PK then
			AddPrefabPostInit("captainhat", EditHats)
			AddPrefabPostInit("snakeskinhat", EditHats)
			AddPrefabPostInit("piratehat", EditHats)
			AddPrefabPostInit("gashat", EditHats)
			AddPrefabPostInit("aerodynamichat", EditHats)
			AddPrefabPostInit("double_umbrellahat", EditHats)
			AddPrefabPostInit("shark_teethhat", EditHats)
			AddPrefabPostInit("brainjellyhat", EditHats)
			AddPrefabPostInit("woodlegshat", EditHats)
		end	
		if PK then
			AddPrefabPostInit("peagawkfeatherhat", EditHats)
			AddPrefabPostInit("gasmaskhat", EditHats)
			AddPrefabPostInit("pithhat", EditHats)
			AddPrefabPostInit("bandithat", EditHats)
			AddPrefabPostInit("thunderhat", EditHats)
			AddPrefabPostInit("hayfeverhat", EditHats)
		end
		if FishHat then
			AddPrefabPostInit("fishbrella", EditHats)
		end
	end
end

-- Edit durability of umbrellas --

if UMBRELLAS ~= "Default" then
	if UMBRELLAS == "Infinite" then	
		AddPrefabPostInit("umbrella", RemoveDurability)	
		if ROG or SW or PK then
			AddPrefabPostInit("grass_umbrella", RemoveDurability)
		end
		if SW or PK then
			AddPrefabPostInit("palmleaf_umbrella", RemoveDurability)
		end
	else			
		function EditUmbrellas(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * UMBRELLAS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * UMBRELLAS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * UMBRELLAS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * UMBRELLAS)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * UMBRELLAS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * UMBRELLAS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * UMBRELLAS)       
			end 
		end
		AddPrefabPostInit("umbrella", EditUmbrellas)	
		if ROG or SW or PK then
			AddPrefabPostInit("grass_umbrella", EditUmbrellas)
		end
		if SW or PK then
			AddPrefabPostInit("palmleaf_umbrella", EditUmbrellas)
		end
	end
end

if FIREPITS ~= "Default" then
	if FIREPITS == "Infinite" then		
		AddPrefabPostInit("firepit", RemoveDurability)		
		if ROG or SW or PK then
			AddPrefabPostInit("coldfirepit", RemoveDurability)
		end
	else			
		function EditFirepits(inst)
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * FIREPITS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * FIREPITS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * FIREPITS)       
			end 
		end
		AddPrefabPostInit("firepit", EditFirepits)
		if ROG or SW or PK then
			AddPrefabPostInit("coldfirepit", EditFirepits)
		end
	end
end

-- Edit durability of portable lights --

if PORTABLE_LIGHT ~= "Default" then
	if PORTABLE_LIGHT == "Infinite" then		
		AddPrefabPostInit("lantern", RemoveDurability)		-- prefab name mininglantern
		AddPrefabPostInit("lighter", RemoveDurability)
		AddPrefabPostInit("minerhat", RemoveDurability)
		AddPrefabPostInit("nightlight", RemoveDurability)
		if ROG == false and SW == false and PK == false then
			AddPrefabPostInit("pumpkin_lantern", RemoveDurability)
		end
		if SW or PK then
			AddPrefabPostInit("bottlelantern", RemoveDurability)
		end
		if PK then
			AddPrefabPostInit("candlehat", RemoveDurability)
			AddPrefabPostInit("bathat", RemoveDurability)
		end
	else			
		function EditPortableLight(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * PORTABLE_LIGHT)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * PORTABLE_LIGHT)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * PORTABLE_LIGHT)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * PORTABLE_LIGHT)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * PORTABLE_LIGHT)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * PORTABLE_LIGHT)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * PORTABLE_LIGHT)       
			end 
		end
		AddPrefabPostInit("lantern", EditPortableLight)
		AddPrefabPostInit("lighter", EditPortableLight)
		AddPrefabPostInit("minerhat", EditPortableLight)
		AddPrefabPostInit("nightlight", EditPortableLight)
		if ROG == false and SW == false and PK == false then
			AddPrefabPostInit("pumpkin_lantern", EditPortableLight)
		end
		if SW or PK then
			AddPrefabPostInit("bottlelantern", EditPortableLight)
		end
		if PK then
			AddPrefabPostInit("candlehat", EditPortableLight)
			AddPrefabPostInit("bathat", EditPortableLight)
		end
	end
end

-- Edit durability of torch --

if TORCH ~= "Default" then
	if TORCH == "Infinite" then		
		AddPrefabPostInit("torch", InfiniteTorch)			
		if EndoTorch then
			AddPrefabPostInit("endothermic_torch", InfiniteTorch)
		end
	else			
		function EditTorch(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * TORCH)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * TORCH)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * TORCH)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * TORCH)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * TORCH)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * TORCH)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * TORCH)       
			end 
		end
		AddPrefabPostInit("torch", EditTorch)
		
		if EndoTorch then
			AddPrefabPostInit("endothermic_torch", EditTorch)
		end
	end
end

-- Edit durability of bedrolls --


if BEDROLLS ~= "Default" then
	if BEDROLLS == "Infinite" then
		function NewBedrollStrawOnsleep(inst, sleeper)
			local GetPlayer = GLOBAL.GetPlayer
			local GetClock = GLOBAL.GetClock
			GetPlayer().HUD:Hide()
			TheFrontEnd:Fade(false,1)
			inst:DoTaskInTime(1.2, function() 
				GetPlayer().HUD:Show()
				TheFrontEnd:Fade(true,1) 
				
				sleeper.sg:GoToState("wakeup")	
				if sleeper.components.hunger then
					sleeper.components.hunger:DoDelta(-TUNING.CALORIES_HUGE, false, true)
				end

				if sleeper.components.sanity then
					sleeper.components.sanity:DoDelta(TUNING.SANITY_LARGE, false)
				end
				GetClock():MakeNextDay()
			end)			
		end
		function NewBedrollFurryOnsleep(inst, sleeper)
			local GetPlayer = GLOBAL.GetPlayer
			local GetClock = GLOBAL.GetClock
			GetPlayer().HUD:Hide()
			TheFrontEnd:Fade(false,1)
			inst:DoTaskInTime(1.2, function() 
				GetPlayer().HUD:Show()
				TheFrontEnd:Fade(true,1) 
				
				sleeper.sg:GoToState("wakeup")	
				if sleeper.components.hunger then
					-- Check SGwilson, state "bedroll", if you change this value
					sleeper.components.hunger:DoDelta(-TUNING.CALORIES_HUGE, false, true)
				end

				if sleeper.components.sanity then
					sleeper.components.sanity:DoDelta(TUNING.SANITY_HUGE, false)
				end

				if sleeper.components.health then
					sleeper.components.health:DoDelta(TUNING.HEALING_MEDLARGE, false, "bedroll", true)
				end
				
				if sleeper.components.temperature then
					sleeper.components.temperature:SetTemperature(sleeper.components.temperature.maxtemp)
				end
				GetClock():MakeNextDay()
			end)			
		end
		function InfiniteStrawBedrolls(inst)
			inst.components.sleepingbag.onsleep = NewBedrollStrawOnsleep
			inst:AddTag("Infinite")
		end
		function InfiniteFurryBedrolls(inst)
			inst.components.sleepingbag.onsleep = NewBedrollFurryOnsleep
			inst:AddTag("Infinite")
		end	
		AddPrefabPostInit("bedroll_straw", InfiniteStrawBedrolls)
		AddPrefabPostInit("bedroll_furry", InfiniteFurryBedrolls)		
	else			
		function EditBedrolls(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * BEDROLLS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * BEDROLLS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * BEDROLLS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * BEDROLLS)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * BEDROLLS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * BEDROLLS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * BEDROLLS)       
			end 
		end
		AddPrefabPostInit("bedroll_furry", EditBedrolls)
		AddPrefabPostInit("bedroll_straw", EditBedrolls)
	end
end

-- Edit durability of shelters --

if SHELTERS ~= "Default" then
	if SHELTERS == "Infinite" then
		if ROG or SW or PK then
			AddPrefabPostInit("siestahut", RemoveDurability)
			AddPrefabPostInit("tent", RemoveDurability)
		end
	else			
		function EditShelters(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * SHELTERS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * SHELTERS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * SHELTERS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * SHELTERS)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * SHELTERS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * SHELTERS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * SHELTERS)       
			end 
		end
		if ROG or SW or PK then
			AddPrefabPostInit("siestahut", EditShelters)
			AddPrefabPostInit("tent", EditShelters)
		end
	end
end

-- Tweak the durability books --
	
if BOOKS ~= "Default" then
	if BOOKS == "Infinite" then
		AddPrefabPostInit("book_sleep", RemoveDurability)
		AddPrefabPostInit("book_gardening", RemoveDurability)
		AddPrefabPostInit("book_brimstone", RemoveDurability)
		AddPrefabPostInit("book_birds", RemoveDurability)			
		AddPrefabPostInit("book_tentacles", RemoveDurability)
		if SW or PK then
			AddPrefabPostInit("book_meteor", RemoveDurability)
		end
	else			
		function EditBooks(inst)		
			if inst.components.finiteuses then
				inst.components.finiteuses.total = (inst.components.finiteuses.total * BOOKS)
				inst.components.finiteuses.current = (inst.components.finiteuses.current * BOOKS)
			end			
			if inst.components.perishable then
				inst.components.perishable.perishtime = (inst.components.perishable.perishtime * BOOKS)
				inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * BOOKS)
			end
			if inst.components.fueled then                                                                  
				inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * BOOKS)           
				inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * BOOKS)   
				inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * BOOKS)       
			end 
		end
		AddPrefabPostInit("book_sleep", EditBooks)
		AddPrefabPostInit("book_gardening", EditBooks)			
		AddPrefabPostInit("book_brimstone", EditBooks)
		AddPrefabPostInit("book_birds", EditBooks)			
		AddPrefabPostInit("book_tentacles", EditBooks)
		if SW or PK then
			AddPrefabPostInit("book_meteor", EditBooks)
		end
	end
end

-- Edit icebox efficiency --

if ICEBOX ~= "Default" then
	TUNING.PERISH_FRIDGE_MULT = ICEBOX
end

--| Specific to shipwreck |--

if SW or PK then

	-- Edit durability of obsidian items --

	if OBSIDIAN_ITEM_BONUS ~= "Default" then
		if OBSIDIAN_ITEM_BONUS == "Infinite" then	
			AddPrefabPostInit("obsidianmachete", RemoveDurability)
			AddPrefabPostInit("obsidianaxe", RemoveDurability)
			AddPrefabPostInit("spear_obsidian", RemoveDurability)
		else
			function EditObsidianItems(inst)		
				if inst.components.finiteuses then
					inst.components.finiteuses.total = (inst.components.finiteuses.total * OBSIDIAN_ITEM_BONUS)
					inst.components.finiteuses.current = (inst.components.finiteuses.current * OBSIDIAN_ITEM_BONUS)
				end			
				if inst.components.perishable then
					inst.components.perishable.perishtime = (inst.components.perishable.perishtime * OBSIDIAN_ITEM_BONUS)
					inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * OBSIDIAN_ITEM_BONUS)
				end
				if inst.components.fueled then                                                                  
					inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * OBSIDIAN_ITEM_BONUS)           
					inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * OBSIDIAN_ITEM_BONUS)   
					inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * OBSIDIAN_ITEM_BONUS)       
				end 
			end
			function ToolInterferenceObsidian(inst)		
				if inst.components.finiteuses then
					inst.components.finiteuses.total = (inst.components.finiteuses.total * OBSIDIAN_DURABILITY * PRIMARY_TOOLS)
					inst.components.finiteuses.current = (inst.components.finiteuses.current * OBSIDIAN_DURABILITY * PRIMARY_TOOLS)
				end			
				if inst.components.perishable then
					inst.components.perishable.perishtime = (inst.components.perishable.perishtime * OBSIDIAN_DURABILITY * PRIMARY_TOOLS)
					inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * OBSIDIAN_DURABILITY * PRIMARY_TOOLS)
				end
				if inst.components.fueled then                                                                  
					inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * OBSIDIAN_DURABILITY * PRIMARY_TOOLS)           
					inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * OBSIDIAN_DURABILITY * PRIMARY_TOOLS)   
					inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * OBSIDIAN_DURABILITY * PRIMARY_TOOLS)       
				end 
			end
			function SpearInterferenceObsidian(inst)		
				if inst.components.finiteuses then
					inst.components.finiteuses.total = (inst.components.finiteuses.total * OBSIDIAN_DURABILITY * SPEARS)
					inst.components.finiteuses.current = (inst.components.finiteuses.current * OBSIDIAN_DURABILITY * SPEARS)
				end			
				if inst.components.perishable then
					inst.components.perishable.perishtime = (inst.components.perishable.perishtime * OBSIDIAN_DURABILITY * SPEARS)
					inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * OBSIDIAN_DURABILITY * SPEARS)
				end
				if inst.components.fueled then                                                                  
					inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * OBSIDIAN_DURABILITY * SPEARS)           
					inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * OBSIDIAN_DURABILITY * SPEARS)   
					inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * OBSIDIAN_DURABILITY * SPEARS)       
				end 
			end
			if PRIMARYTOOL_DURABILITY ~= "Default" then
				if PRIMARYTOOL_DURABILITY ~= "Infinite" then
					AddPrefabPostInit("obsidianmachete", ToolInterferenceObsidian)
					AddPrefabPostInit("obsidianaxe", ToolInterferenceObsidian)
				end
			else
				AddPrefabPostInit("obsidianmachete", EditObsidianItems)
				AddPrefabPostInit("obsidianaxe", EditObsidianItems)
			end
			if WEAPON_DURABILITY ~= "Default" then
				if WEAPON_DURABILITY ~= "Infinite" then
					AddPrefabPostInit("spear_obsidian", SpearInterferenceObsidian)
				else
					AddPrefabPostInit("spear_obsidian", EditObsidianItems)
				end
			end
		end
	end
	
	-- Edit durability of boats --
	
	if BOATS ~= "Default" then
		if BOATS == "Infinite" then
			AddPrefabPostInit("rowboat", RemoveDurability)
			AddPrefabPostInit("raft", RemoveDurability)
			AddPrefabPostInit("lograft", RemoveDurability)
			AddPrefabPostInit("surfboard", RemoveDurability)
			AddPrefabPostInit("cargoboat", RemoveDurability)
			AddPrefabPostInit("armouredboat", RemoveDurability)
			AddPrefabPostInit("encrustedboat", RemoveDurability)
			AddPrefabPostInit("woodlegsboat", RemoveDurability)
			if PK then
				AddPrefabPostInit("corkboat", RemoveDurability)
			end
		else			
			function EditBoats(inst)
				inst.components.boathealth.maxhealth = (inst.components.boathealth.maxhealth * BOATS)
				inst.components.boathealth.currenthealth = (inst.components.boathealth.currenthealth * BOATS)
				if inst.components.finiteuses then
					inst.components.finiteuses.total = (inst.components.finiteuses.total * BOATS)
					inst.components.finiteuses.current = (inst.components.finiteuses.current * BOATS)
				end			
				if inst.components.perishable then
					inst.components.perishable.perishtime = (inst.components.perishable.perishtime * BOATS)
					inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * BOATS)
				end
				if inst.components.fueled then                                                                  
					inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * BOATS)           
					inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * BOATS)   
					inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * BOATS)       
				end 
			end
			AddPrefabPostInit("rowboat", EditBoats)
			AddPrefabPostInit("raft", EditBoats)
			AddPrefabPostInit("lograft", EditBoats)
			AddPrefabPostInit("surfboard", EditBoats)
			AddPrefabPostInit("cargoboat", EditBoats)
			AddPrefabPostInit("armouredboat", EditBoats)
			AddPrefabPostInit("encrustedboat", EditBoats)
			AddPrefabPostInit("woodlegsboat", EditBoats)
			if PK then
				AddPrefabPostInit("corkboat", EditBoats)
			end
		end
	end
	
	-- Edit durability of sails --
	
	if SAILS ~= "Default" then
		if SAILS == "Infinite" then		
			AddPrefabPostInit("sail", RemoveDurability)
			AddPrefabPostInit("clothsail", RemoveDurability)
			AddPrefabPostInit("snakeskinsail", RemoveDurability)
			AddPrefabPostInit("feathersail", RemoveDurability)
			AddPrefabPostInit("ironwind", RemoveDurability)
			AddPrefabPostInit("woodlegssail", RemoveDurability)
		else			
			function EditSails(inst)		
				if inst.components.finiteuses then
					inst.components.finiteuses.total = (inst.components.finiteuses.total * SAILS)
					inst.components.finiteuses.current = (inst.components.finiteuses.current * SAILS)
				end			
				if inst.components.perishable then
					inst.components.perishable.perishtime = (inst.components.perishable.perishtime * SAILS)
					inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * SAILS)
				end
				if inst.components.fueled then                                                                  
					inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * SAILS)           
					inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * SAILS)   
					inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * SAILS)       
				end 
			end
			AddPrefabPostInit("sail", EditSails)
			AddPrefabPostInit("clothsail", EditSails)
			AddPrefabPostInit("snakeskinsail", EditSails)
			AddPrefabPostInit("feathersail", EditSails)
			AddPrefabPostInit("ironwind", EditSails)
			AddPrefabPostInit("woodlegssail", EditSails)
		end
	end
	
	-- Edit durability of boat items --
	
	if BOAT_ITEMS ~= "Default" then
		if BOAT_ITEMS == "Infinite" then		
			AddPrefabPostInit("boatcannon", RemoveDurability)
			AddPrefabPostInit("boat_lantern", RemoveDurability)
			AddPrefabPostInit("telescope", RemoveDurability)
			AddPrefabPostInit("supertelescope", RemoveDurability)
			AddPrefabPostInit("boat_indicator", RemoveDurability)
			AddPrefabPostInit("boat_torch", RemoveDurability)
			AddPrefabPostInit("woodlegs_boatcannon", RemoveDurability)
			AddPrefabPostInit("quackeringram", RemoveDurability)
		else
			function EditBoatItems(inst)		
				if inst.components.finiteuses then
					inst.components.finiteuses.total = (inst.components.finiteuses.total * BOAT_ITEMS)
					inst.components.finiteuses.current = (inst.components.finiteuses.current * BOAT_ITEMS)
				end			
				if inst.components.perishable then
					inst.components.perishable.perishtime = (inst.components.perishable.perishtime * BOAT_ITEMS)
					inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * BOAT_ITEMS)
				end
				if inst.components.fueled then                                                                  
					inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * BOAT_ITEMS)           
					inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * BOAT_ITEMS)   
					inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * BOAT_ITEMS)       
				end 
			end
			AddPrefabPostInit("boatcannon", EditBoatItems)
			AddPrefabPostInit("boat_lantern", EditBoatItems)
			AddPrefabPostInit("telescope", EditBoatItems)
			AddPrefabPostInit("supertelescope", EditBoatItems)
			AddPrefabPostInit("boat_indicator", EditBoatItems)
			AddPrefabPostInit("boat_torch", EditBoatItems)
			AddPrefabPostInit("woodlegs_boatcannon", EditBoatItems)
			AddPrefabPostInit("quackeringram", EditBoatItems)
		end
	end
	
	-- Edit durability of boat repairkit --
	
	if BOAT_REPAIRKIT ~= "Default" then
		if BOAT_REPAIRKIT == "Infinite" then		
			AddPrefabPostInit("boatrepairkit", RemoveDurability)
		else			
			function TweakBoatRepairKit(inst)		
				if inst.components.finiteuses then
					inst.components.finiteuses.total = (inst.components.finiteuses.total * BOAT_REPAIRKIT)
					inst.components.finiteuses.current = (inst.components.finiteuses.current * BOAT_REPAIRKIT)
				end			
				if inst.components.perishable then
					inst.components.perishable.perishtime = (inst.components.perishable.perishtime * BOAT_REPAIRKIT)
					inst.components.perishable.perishremainingtime = (inst.components.perishable.perishremainingtime * BOAT_REPAIRKIT)
				end
				if inst.components.fueled then                                                                  
					inst.components.fueled.maxfuel = (inst.components.fueled.maxfuel * BOAT_REPAIRKIT)           
					inst.components.fueled.currentfuel = (inst.components.fueled.currentfuel * BOAT_REPAIRKIT)   
					inst.components.fueled.bonusmult = (inst.components.fueled.bonusmult * BOAT_REPAIRKIT)       
				end 
			end
			AddPrefabPostInit("boatrepairkit", TweakBoatRepairKit)
		end
	end
end

-- Infinitize blowdarts --

if BLOWDART_USE ~= "Default" then
	
	local function NewOnThrown(inst, data)
		local ANIM_ORIENTATION = GLOBAL.ANIM_ORIENTATION
		local Player = GLOBAL.GetPlayer()
		inst.AnimState:SetOrientation( ANIM_ORIENTATION.OnGround )
	
		if inst.prefab == "blowdart_pipe" then
			local item = SpawnPrefab("blowdart_pipe")
		elseif inst.prefab == "blowdart_sleep" then
			local item = SpawnPrefab("blowdart_sleep")
		elseif inst.prefab == "blowdart_fire" then
			local item = SpawnPrefab("blowdart_fire")
		elseif inst.prefab == "blowdart_poison" then
			local item = SpawnPrefab("blowdart_poison")
		elseif inst.prefab == "needle_dart" then
			local item = SpawnPrefab("needle_dart")
		elseif inst.prefab == "needle_dart_fire" then
			local item = SpawnPrefab("needle_dart_fire")
		end
		Player.components.inventory:Equip(item)
	end
	function TweakDarts(inst)
		inst:ListenForEvent("onthrown", NewOnThrown)
		inst:RemoveComponent("stackable")
	end
	AddPrefabPostInit("blowdart_sleep", TweakDarts)
	AddPrefabPostInit("blowdart_fire", TweakDarts)
	AddPrefabPostInit("blowdart_pipe", TweakDarts)
	if SW then
		AddPrefabPostInit("blowdart_poison", TweakDarts)
		AddPrefabPostInit("needle_dart", TweakDarts)
		AddPrefabPostInit("needle_dart_fire", TweakDarts)
	end
	--[[     --To do
	function NewOnPoked(inst, worker, stick)
		local function onpoked(inst, worker, stick)
		local Player = GLOBAL.GetPlayer()
		inst.SoundEmitter:PlaySound("dontstarve_DLC002/common/plant_mussel")
		inst.components.growable:SetStage(3)
	
		if stick.components.stackable and stick.components.stackable.stacksize > 1 then
			stick = stick.components.stackable:Get()
		end
		local item = SpawnPrefab("mussel_farm")
		Player.components.inventory:GiveItem(item)
		--stick:Remove()
		end
	end
	function TweakMusselStick(inst)
		inst.components.stickable:SetOnPokeCallback(NewOnPoked)
	end
	AddPrefabPostInit("mussel_farm", TweakMusselStick)
	--]]
end
if WALLS ~= "Default" then	
	local function InfiniteWalls(inst)
		inst.components.health:SetAbsorptionAmount(1)
	end
	AddPrefabPostInit("wall_stone", InfiniteWalls)
	AddPrefabPostInit("wall_wood", InfiniteWalls)
	AddPrefabPostInit("wall_hay", InfiniteWalls)
	AddPrefabPostInit("wall_ruins", InfiniteWalls)
	if SW then
		AddPrefabPostInit("wall_limestone", InfiniteWalls)
	end
end



--